package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````X1H!`#0```!<LP```@0`!30`(``)
M`"@`'``;``$``'"\I@``O*8!`+RF`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#(I@``R*8```4```````$`
M`0```-RN``#<K@(`W*X"`%@"``"@$@``!@```````0`"````Z*X``.BN`@#H
MK@(`&`$``!@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DW*X`
M`-RN`@#<K@(`)`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50#H'Z/@+:3R5WAY43K#K,B:\A/)C&$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````F0,`````````
M````$@```%P"`````````````!(```#S`@`````````````2````UP(`````
M````````$@```)H$```DL0(``````"``%P#-`0`````````````2````T`(`
M````````````$@```+T!```0%@$``````!(````F!0``'68!`#`````2``T`
M`P0``#2Q`@``````$``8`(H"`````````````!(```"U`@`````````````2
M````V@0``#"Q`@`$````$0`7`#8#`````````````!(```!"!0``X6(!`/`"
M```2``T`?P0```U8`0"H````$@`-`*`#`````````````!(```";`@``````
M```````2````1P,`````````````$@```!($``!\P0(``````!``&``/`0``
M```````````2````700`````````````$@```(L$``!56P$`C`<``!(`#0"T
M!```W54!`)(````2``T`<@0``/57`0`6````$@`-`,("`````````````!(`
M``"%`@`````````````2````E@$`````````````$@```",#````````````
M`!(```"S`P``.+$"``0````A`!@`1`(`````````````$@```$L"````````
M`````!(```#E`@`````````````2````\`,``#2Q`@``````$``7```#````
M`````````!(```">````4!@!```````2````R@(`````````````$@```&L#
M`````````````!(````^`@`````````````2````9`(`````````````$@``
M`+0#```XL0(`!````"$`&``=!```?,$"```````0`!@`0`,``%"Q`@`$````
M$0`8`"H$``"A9@$``@```!(`#0"A`0`````````````2````;P$`````````
M````$@```,H$``!A9@$`0````!(`#0`&!0``G5H!`+@````2``T`-`0``*1F
M`0``````$@`.`*0"`````````````!(```">!```X1H!```````2``T`\P0`
M`'@5`0``````$@`+`+X``````````````!(````5`P`````````````2````
M`@$``$RQ`@`!````$0`8`-X"`````````````!(```"E!```K&8!``0````1
M``\`]P,``#2Q`@``````$``8`'(#`````````````!(```"*`P``````````
M```2````:@``````````````$@```!P!`````````````!(```#Q!```:54!
M`#`````2``T`.`$`````````````$@```"4$``!\P0(``````!``&`#Y!```
M=58!`'X!```2``T`TP``````````````$@```',"`````````````!(```"'
M```````````````2````*@(`````````````$@```*\!`````````````!(`
M``#A```````````````2````\P``````````````$@```"T!``!(L0(`!```
M`!$`&`"R`P``.+$"``0````1`!@`80$`````````````$@```.P"````````
M`````!(````1!```?,$"```````0`!@`&`4``#U:`0!0````$@`-`*\`````
M`````````!(````N`P`````````````2````F`0``"2Q`@``````$``7`'P#
M`````````````!(```#0`P``0+$"``0````1`!@`2P0``(U:`0`0````$@`-
M`.L!`````````````!(```#8`0`````````````2````K0,``.D8`0#X`0``
M$@`-`#T!`````````````!(```!7`P`````````````2````3@,`````````
M````$@```/8!``!4L0(`$P```!$`&``.`P`````````````2````^@(`````
M````````$@```)("`````````````!(```#D`0`````````````2````D@,`
M````````````$@```.0$``"U6`$`B`$``!(`#0!>`P`````````````2````
M0@$`````````````$@```+P"`````````````!(```!F!```T64!`$P````2
M``T`>```````````````$@```'\!`````````````!(````Z!```<58!``0`
M```2``T`B`$`````````````$@```$X!``#8%P$``````!(`````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R
M;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P
M<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E
M;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``
M7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M
M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I
M<F]N`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS
M7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C0```````````````(``P`"``(``0````(`
M```!``$``@`"``$``@`!``$``@`"``(``0````(``0`!``$``@`"`````@`"
M``,``P`"``$``@````(``@`#``,``@`!``(``0```````0`!``$``@`!``$`
M```"`````@`!``$``@`"```````!`````0`!`````@````,````````````"
M`````@`!``$````"``$``@`$``$```````$``@`"``(````"``(``@`"``(`
M`0`"`````@`!```````!``````````$``0"\`P``$````"`````4:6D-```$
M`%@%`````````0`!`!H"```0````(````!1I:0T```,`6`4````````!``$`
M:0(``!``````````%&EI#0```@!8!0```````""Q`@`5`@``.+$"`!1/``!`
ML0(`%%@``$BQ`@`43@``3+$"`!0[``!0L0(`%"\``%2Q`@`48```#+`"`!8'
M```0L`(`%@4``!2P`@`6&@``&+`"`!8L```<L`(`%A<``""P`@`60```)+`"
M`!9=```HL`(`%D<``"RP`@`680``,+`"`!9>```TL`(`%@P``#BP`@`68@``
M/+`"`!94``!`L`(`%D0``$2P`@`6.@``2+`"`!8V``!,L`(`%D@``%"P`@`6
M$```5+`"`!8>``!8L`(`%C$``%RP`@`64```8+`"`!9?``!DL`(`%F<``&BP
M`@`63```;+`"`!9:``!PL`(`%@8``'2P`@`6;@``>+`"`!9;``!\L`(`%E4`
M`("P`@`6(P``A+`"`!9D``"(L`(`%A4``(RP`@`6,@``D+`"`!8"``"4L`(`
M%@@``)BP`@`6'P``G+`"`!8E``"@L`(`%FL``*2P`@`6*@``J+`"`!89``"L
ML`(`%B0``+"P`@`65P``M+`"`!8Y``"XL`(`%F,``+RP`@`6(```P+`"`!9I
M``#$L`(`%E$``,BP`@`6;P``S+`"`!9!``#0L`(`%F@``-2P`@`6"@``V+`"
M`!8G``#<L`(`%D(``."P`@`6"P``Y+`"`!9E``#HL`(`%CP``.RP`@`62P``
M\+`"`!8H``#TL`(`%C\``/BP`@`630``_+`"`!9L````L0(`%DD```2Q`@`6
M$@``"+$"`!8/```,L0(`%BD``!"Q`@`6*P``%+$"`!8A```8L0(`%A8``!RQ
M`@`62@``"$`MZ6,!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y6R:`0``QH_B&<J,
MXFSZO.4`QH_B&<J,XF3ZO.4`QH_B&<J,XESZO.4`QH_B&<J,XE3ZO.4`QH_B
M&<J,XDSZO.4`QH_B&<J,XD3ZO.4`QH_B&<J,XCSZO.4`QH_B&<J,XC3ZO.4`
MQH_B&<J,XBSZO.4`QH_B&<J,XB3ZO.4`QH_B&<J,XASZO.4`QH_B&<J,XA3Z
MO.4`QH_B&<J,X@SZO.4`QH_B&<J,X@3ZO.4`QH_B&<J,XOSYO.4`QH_B&<J,
MXO3YO.5X1\!&`,:/XAG*C.+H^;SE`,:/XAG*C.+@^;SE`,:/XAG*C.+8^;SE
M`,:/XAG*C.+0^;SE`,:/XAG*C.+(^;SE`,:/XAG*C.+`^;SE`,:/XAG*C.*X
M^;SE`,:/XAG*C.*P^;SE`,:/XAG*C.*H^;SE`,:/XAG*C.*@^;SE`,:/XAG*
MC.*8^;SE`,:/XAG*C.*0^;SE`,:/XAG*C.*(^;SE`,:/XAG*C.*`^;SE`,:/
MXAG*C.)X^;SE`,:/XAG*C.)P^;SE`,:/XAG*C.)H^;SE`,:/XAG*C.)@^;SE
M`,:/XAG*C.)8^;SE`,:/XAG*C.)0^;SE`,:/XAG*C.)(^;SE`,:/XAG*C.)`
M^;SE`,:/XAG*C.(X^;SE`,:/XAG*C.(P^;SE`,:/XAG*C.(H^;SE`,:/XAG*
MC.(@^;SE`,:/XAG*C.(8^;SE>$?`1@#&C^(9RHSB#/F\Y7A'P$8`QH_B&<J,
MX@#YO.4`QH_B&<J,XOCXO.4`QH_B&<J,XO#XO.4`QH_B&<J,XNCXO.4`QH_B
M&<J,XN#XO.4`QH_B&<J,XMCXO.4`QH_B&<J,XM#XO.4`QH_B&<J,XLCXO.4`
MQH_B&<J,XL#XO.4`QH_B&<J,XKCXO.4`QH_B&<J,XK#XO.4`QH_B&<J,XJCX
MO.4`QH_B&<J,XJ#XO.4`QH_B&<J,XICXO.4`QH_B&<J,XI#XO.4`QH_B&<J,
MXHCXO.4`QH_B&<J,XH#XO.5X1\!&`,:/XAG*C.)T^+SE`,:/XAG*C.)L^+SE
M`,:/XAG*C.)D^+SE`,:/XAG*C.)<^+SE`,:/XAG*C.)4^+SE`,:/XAG*C.),
M^+SE`,:/XAG*C.)$^+SE`,:/XAG*C.(\^+SE`````"WI\$-+\D`9P/(""8FP
MV?@`,`60!:@$D02I`Y(#J@>3__<F[T'RV'%!]E``P/(!`<#R`0`*1@3PE_Y+
M\DP3P/("`QUX`"T`\)&`2_)(%,#R`@0@:/_WS.^0^-XS`D8@:$/P`@."^-XS
M__?"[P6;G^U>6P4S!^Z0.I_M76NX[F=[-^X%>[3NQGOQ[A#ZD/C>(T+P`0*`
M^-XC`/.)@)@`3/)@*/_WJNX$GDOR+!,%FL#R`@/`\@((7&@!*D;V0"%&]D0C
MP/(!`<#R`0,'1C!H2/CP?+Q@R+\'\0P$.&!/\`0`>6#(OS$=^V#(OP;K@@9(
M^/0,!=U1^`1;L4)$^`1?^=$"\8!$1?*940,T`"4[1@"56/CH#`,R1_@D4,#R
M`0'_]_KN3/)@(\#R`@,$1IBS6/CH#$SR8"7_]S#N1O+P<`:IP/(!`,#R`@4#
M\"K[2+-8^.@,__?\[?_WTNX'FMGX`#`@1II".=$)L+WH\(/_]S+N3/)@(\#R
M`@-#^.@,>+-+\D@4__?>[<#R`@0@:/_W,.^`^"U67>=3^.@,__?X[@1&Q>=5
M^.P,8+$$\)[]S^=&]AP02_)4$<#R`0#`\@(!__=V[D;RC'`&J<#R`0`#\.CZ
M1?CL#``HNM#FY__WQ.T!(/_W.NZO\P"``````````````(#____/04_P``M/
M\``.`KQJ1@2T`;3?^!#`3?@$S0-(!$O_]PCN__?2[J%F`0#I&`$`868!`!0P
MG^44()_E`S"/X`(@D^<``%+C'O\O`?[^_^K@E`$`(`$```=+2_(T$,#R`@`;
M&@8K!=E`\@`#P/(``P.Q&$=P1P"_-[$"`$OR-!-+\C00P/("`\#R`@`9&HD0
M`>O1<4D0!=!`\@`#P/(``P.Q&$=P1P"_$+5+\F<4P/("!"-X&[G_]\__`2,C
M<!"]2O;D8`BUP/("``-H$[F]Z`A`T^=`\@`#P/(``P`K]M"81_3G+>GP3TOR
M0!.M]3]]P/("`PWQ>`D`\3@'&Y,`\7@,&VA.1AJ0S?@HD+V3S>D,JY?H"@`(
M-V=%3^H3:T_J$R5/ZA%J3^H!(DKJ`RI/ZA$D`))$Z@-DS?@$H$_J`R)/Z@-N
M`I+=Z0`C3_```YE&3^H!803T?T`"]'\"3_```\WX#+`%DTM&0NH!`D_P``&`
M1HE&W>D"`4_P``$$E0#T?P#-^!BP0.H.`,WI"`%`1D#J`@!/\``!!Y%)1D'J
M`P$"1@KP_P`+1D+J``A/\``!0^H!"=WI!`%/\``!W>D((P#T?T!&Z0*)0NH`
M`D/J`0,01AE&W>D&(T_P``-#Z@$#`O#_`D+J``(91A!&YN@$`8_1W?@HD`WQ
MT`XJJ!JI#?'H#$_P0`CYZ0)G\.D"(_[I`D7-Z0!G@NH$!H/J!0?QZ0)%,D8[
M1MWI`&=60%]`9D!O0+09N/$!"$_JUGI/\``#2NI'"DKJ!`8R1NSI`B/:T1J<
M#?4^?G[IH@'4Z0`CU.D(9Y!&F49%1@`B`"/M#LWI`".21@"5)4;-Z11GFT8`
MGLWI`HE&ZDD4U>D"9P"4+$9-1LWI#&?M#M3I!F<!E25&1$;=Z12)8@'-Z1!G
M&.L`"-WI#&=)ZP$)U>D$14!&24;=Z0")S>D.14CJ`@@/]M13T^D`(Q(82T'=
MZ1`!S>D$(R#J!@(AZ@<#,$8Y1B!`*4#-Z08C,D;=Z09%.T8&1@]&4$991LWI
M``$T0]WI!`$61CU#3^J2"A#K"``?1D'Q``$"&4_J@W,!DT'K!0.01@`B2NJ'
M>IE&`9O-Z0:)3^K89$/JE@,!D[,'`),`(\WI!"/=Z0`C3_``"0`E3^I($$+J
M"@+>Z0*K!)3=Z0)G%$8$F\WI"$5#ZDD3,D8$DR)`.T8K0!1&,D8=1CM&W>D.
M9R;J`@(GZ@,#W>D09\WI`"-/ZMEC%NL*!@631^L+!]WI`*M*Z@0*2^H%"P_V
MZ$75Z0!%I!E]0=WI!&<B1@`D!D,2ZPH`*T9#ZPL!W>D"JP`ES>D`15)&DPB"
M&0"30?$``Q9&6D8?1@";4$;-Z1)G0^J+<P"3DP@!DP`B`"/-Z00CLD;=Z0`C
MA`?V#@26(D,$FT_P``L`)Q9&0^I+$P233^I*$-WI!B,`(=[I!$4R0#M`S>D*
M9Q9&'T;=Z0XC$AE/ZMMD:T$%E`_V3$75Z0!%I!@R1EU!S>D&1=WI"$4[1MWI
M!&<DZ@@$)>H)!2)#*T,&0T_JB'`41AU&`"(`(\WI`"/=Z08C$AEK09(9WND&
M9QU&3^J8`P"3D$8`G$7Q``/-Z18C1.J)=`"43^J9!`&4W>D`(P`C3_``"4_J
MV&0"0T3J21001@`BS>D`(P_VR#/3Z0`CS>D&`4_J21&2&0&1>T'=Z1(!W>D&
M9P&4,$`Y0-WI"&>V&%]!W>D*(\WI!&<&1B+J"@(CZ@L##T860Q]#3^I($3)&
M`)$[1MWI!&?=Z0`!MAA/\``"7T$`(\WI!"-/ZIH#!),@0P29,AA'\0`#3^J*
M=$'JBW$$D4_JFP$%D9)&S>D2(]WI!",`(][I"&=/\``+(D,`(4_JVF001@`B
MS>D`(T3J2Q0/]APST^D`(\WI"`%/ZDL1DAD!D7M!W>D6`=WI"&<!E#!`.4#=
MZ0IGMAA?0=WI!B/-Z01G!D8BZ@@"(^H)`P]&%D,?0T_J2A$R1@"1.T;=Z01G
MW>D``;883_```E]!`"/-Z00C3^J8`P23($,$F3(81_$``T_JB'1!ZHEQ!)%/
MZID!!9&01LWI%B/=Z00C`"/>Z0IG3_``"2)#`"%/ZMAD$$8`(LWI`"-$ZDD4
M#_9P(]/I`"/-Z0H!3^I)$9(9`9%[0=WI$@'=Z0IG`90P0#E`W>D&9[887T'=
MZ0@CS>D$9P9&(NH*`B/J"P,/1A9#'T-/ZD@1,D8`D3M&W>D$9]WI``&V&$_P
M``)?00`CS>D$(T_JF@,$DR!#!)DR&$?Q``-/ZHIT0>J+<0213^J;`061DD;>
MZ0QGS>D2(T_P``O=Z00C`",`(2)#3^K:9$3J2Q001@`BS>D`(P_VQ!/3Z0`C
MS>D&`4_J2Q&2&0&1>T'=Z18!W>D&9P&4,$`Y0-WI"&>V&%]!W>D*(\WI!&<&
M1B+J"`(CZ@D##T860Q]#3^I*$3)&`)$[1MWI!&?=Z0`!MAA/\``"7T$`(\WI
M!"-/ZI@#!),@0P29,AA'\0`#3^J(=$'JB7$$D4_JF0$%D9!&S>D6(]WI!",`
M(][I#F=/\``)(D,`(4_JV&001@`BS>D`(T3J210/]A@3T^D`(\WI"`%/ZDD1
MDAD!D7M!W>D2`=WI"&<!E#!`.4#=Z0IGMAA?0=WI!B/-Z01G!D8BZ@H"(^H+
M`P]&%D,?0T_J2!$R1@"1.T;=Z01GMAA/\``"7T$`(\WI!"-/ZIH#W>D``023
M!)D@0S(83^J*=$'JBW$$D4_JFP$%D9)&1_$``\WI$B-/\``+W>D$(P`CWND0
M9P`A(D-/ZMID1.I+%!!&`"+-Z0`C#_9L`]/I`"/-Z0H!3^I+$9(9`9%[0=WI
M%@'=Z0IG`90P0#E`W>D&9[887T'=Z0@CS>D$9P9&(NH(`B/J"0,/1A9#'T-/
MZDH1,D8`D3M&W>D$9]WI``&V&$_P``)?00`CS>D$(T_JF`,$DR!#!)DR&$?Q
M``-/ZHAT0>J)<0213^J9`061D$;-Z18CW>D$(P`CWND29T_P``DB0P`A3^K8
M9!!&`"+-Z0`C1.I)%`_RP'/3Z0`CS>D&`4_J21&2&0&1>T'=Z1(!W>D&9P&4
M,$`Y0-WI"&>V&%]!W>D*(\WI!&<&1B+J"@(CZ@L##T860Q]#3^I($3)&`)$[
M1MWI!&?=Z0`!MAA/\``"7T$`(\WI!"-/ZIH#!),@0P29,AA'\0`#3^J*=$'J
MBW$$D4_JFP$%D9)&S>D2(]WI!",`(][I%&=/\``+(D,`(4_JVF001@`BS>D`
M(T3J2Q0/\A1ST^D`(\WI"`%/ZDL1DAD!D7M!W>D6`=WI"&<!E#!`.4#=Z0IG
MMAA?0=WI!B/-Z01G!D8BZ@@"(^H)`P]&%D,?0T_J2A$R1@"1.T;=Z01GW>D`
M`;883_```E]!`"/-Z00C3^J8`P23($,$F3(81_$``T_JB'1!ZHEQ!)%/ZID!
M!9&01M[I%F?-Z18C3_``"=WI!",`(P`A(D-/ZMAD1.I)%!!&`"+-Z0`C#_)H
M8]/I`"/-Z0H!3^I)$9(9`9%[0=WI$@'=Z0IG`90P0#E`W>D&9[887T'=Z0@C
MS>D$9P9&(NH*`B/J"P,/1A9#'T-/ZD@1,D8`D3M&W>D$9]WI``&V&$_P``)?
M00`CS>D$(T_JF@,$DR!#!)DR&$?Q``-/ZHIT0>J+<0213^J;`061DD;-Z1(C
MW>D$(P`CWND89T_P``LB0P`A3^K:9!!&`"+-Z0`C1.I+%`_RO%/3Z0`CS>D&
M`4_J2Q&2&0&1>T'=Z18!W>D&9P&4,$`Y0-WI"&>V&%]!W>D*(\WI!&<&1B+J
M"`(CZ@D##T860Q]#3^I*$3)&`)$[1MWI!&>V&$_P``)?00`CS>D$(T_JF`/=
MZ0`!!),$F2!#,AA/ZHAT0>J)<0213^J9`061D$9'\0`#S>D6(T_P``G=Z00C
M`"/>Z1IG`"$B0T_JV&1$ZDD4$$8`(LWI`",/\A!3T^D`(\WI"`%/ZDD1DAD!
MD7M!W>D2`=WI"&<!E#!`.4#=Z0IGMAA?0=WI!B/-Z01G!D8BZ@H"(^H+`P]&
M%D,?0T_J2!$R1@"1.T;=Z01GW>D``;883_```E]!`"/-Z00C3^J:`P23($,$
MF3(81_$``T_JBG1!ZHMQ!)%/ZIL!!9&21LWI$B/=Z00C`"/>Z1QG3_``"R)#
M`"%/ZMID$$8`(LWI`"-$ZDL4#_)D0]/I`"/-Z0H!3^I+$9(9`9%[0=WI%@'=
MZ0IG`90P0#E`W>D&9[887T'=Z0@CS>D$9P9&(NH(`B/J"0,/1A9#'T-/ZDH1
M,D8`D3M&W>D$9]WI``&V&$_P``)?00`CS>D$(T_JF`,$DR!#!)DR&$?Q``-/
MZHAT0>J)<0213^J9`061D$;-Z18CW>D$(P`CWND>9T_P``DB0P`A3^K89!!&
M`"+-Z0`C1.I)%.ZCT^D`(\WI!@%/ZDD1DAD!D7M!W>D2`=WI!F<!E#!`.4#=
MZ0AGMAA?0=WI"B/-Z01G!D8BZ@H"(^H+`P]&%D,?0T_J2!$R1@"1.T;=Z01G
MW>D``;883_```E]!`"/-Z00C3^J:`P23($,$F3(81_$``T_JBG1!ZHMQ!)%/
MZIL!!9&21M[I(&?-Z1(C3_``"]WI!",`(P`A(D-/ZMID1.I+%!!&`"+-Z0`C
MQ*/3Z0`CS>D(`4_J2Q&2&0&1>T'=Z18!W>D(9P&4,$`Y0-WI"F>V&%]!W>D&
M(\WI!&<&1B+J"`(CZ@D##T860Q]#3^I*$3)&`)$[1MWI!&?=Z0`!MAA/\``"
M7T$`(\WI!"-/ZI@#!),@0P29,AA'\0`#3^J(=$'JB7$$D4_JF0$%D9!&S>D6
M(]WI!",`(][I(F=/\``)(D,`(4_JV&001@`BS>D`(T3J2129H]/I`"/-Z0H!
MDAE[0<WI!"-/ZDD3`9/=Z1(CW>D&9P)`"T`!E!!&&4;=Z00CDAE[019&'T;=
MZ0@CS>D$9P9&(NH*`B/J"P,/1A9#'T-/ZD@1,D8`D3M&W>D$9[883_```E]!
M`"/-Z00C3^J:`]WI``$$DP29($,R&$_JBG1'\0`#0>J+<0`G!)%/ZIL!!9&2
M1M[I)`'-Z08C`";=Z00C.T8`)\WI`&=OI]?I`&=/\``+(D/-Z00C-AA/ZMID
M3T%/ZDL1`9%$ZDL4W>D6`0&4$$`90-WI"".2&7M!%D8?1MWI"B,BZ@@"(^H)
M`P)#"T.0&4_J2A$`D4/K!P'=Z0`C`"8`)T_JB',B0SU&-$9/ZI@&S>D`14_J
MB70!E(08`)-!\0`%1NJ)=LWI"$4!E@`E($8I1MWI`$5/ZID'WNDF(S1#/4-&
M`:!&J48`)``ES>D`1<0.`)1$I=7I`$7-Z1*)I!A=02)&`)PK1@`EJ49$ZD$4
M`)3=Z09%S>D6B03J"`0%Z@D%W>D*B1CK`@A)ZP,)W>D$(R+J"@(CZ@L#(D,K
M0QCK`@A/ZM%D2>L#"0&40D9/ZHIT2T;=Z0")2.H&"!+K"`;=Z1*)0_$`!T_J
MD0DR1D_JF@9&ZHMV`)8[1D_JTFHU1D_JFP8!EMWI`&?-Z0HC`",F0R]#B.H&
M",WI!F?>Z2A%2NI#&AJGU^D`9\WX!*"D&7U!)D8O1MWI"$6$Z@@$H$;=Z01%
MI!E]029&%NL(!$7Q``7-Z01%5`$`E-WI`$5/ZI`(2.J!>(8'2.H&`$3J"@3=
MZ09G2>H(`=WI!*N?",WI!`$(X`"_F7F"6@````"AZ]EN`````$9`&NL$"@_V
M>&'1Z0`!WNDJ14OQ``M/ZMIHS>D2JP`93_``"VE!2.I+&`1&S?@$@`U&W>D*
M`7!`!D;=Z18!`!E/ZH)T:4&`&4_JD@8-1D7Q``'-Z0@!3^I*$0"11NJ#=MWI
M``%&Z@0"W>D$14?J!@-`Z@@`W>D(B51`S>D((QCK``@/]OQ3T^D`(][I+`%)
M\0`)3^K89LWI"HD2&$_P``E+04;J21801@&6&4;=Z1(C3^J;!6)`%$8&FH`8
M0?$``0(90?$``\WI!B-/ZD@3`)/=Z0`C3^J:!$3JBW1/ZHIP,D/=Z09G1.H`
M"D7J!`NV&-WI"$5'\0`'4$8R1EE&.T;-Z1(C`"/-Z08!'T9$0-[I+B-/ZM9J
M#_9H4='I``%*ZD<:S?@$H$_JF06`&%E!W>D*(V)`%$8$FH`80?$``0(90?$`
M`\WI!"-S`0"3W>D`(T_JF`1$ZHET3^J(<$+J"@)$Z@`(W>D$JT7J!`G=Z09%
M0$8:ZP(*24;>Z3`CA.H`!,WI!`%+\0`+#_;T0='I``%/ZMIHS>D*JT_P``N`
M&$CJ2QA90=WI$B/-^`2`O0AB0!1&")J`&$'Q``$"&4'Q``/-Z0@C3^I*$P"3
MW>D`([0(1.J'=+`'1.H`!D+J"`)%Z@0'W>D(B3!&W>D$11CK`@@Y1M[I,B-)
M\0`)S>D(`71`#_9\0='I``%/ZMAFS>D2B4_P``F`&$;J21990=WI"B,!ED_J
MFP5B0!1&!IJ`&$'Q``$"&4'Q``/-Z08C3^I($P"3W>D`(T_JF@1$ZHMT3^J*
M<#)#W>D&9T3J``I%Z@0+MAC=Z0A%1_$`!U!&,D991CM&S>D*(P`CS>D&`1]&
M1$#>Z30C3^K6:@_V]#'1Z0`!2NI'&LWX!*!/ZID%@!A90=WI$B-B0!1&!)J`
M&$'Q``$"&4'Q``/-Z00C<P$`D]WI`"-/ZI@$1.J)=$_JB'!"Z@H"1.H`"-WI
M!*M%Z@0)W>D&14!&&NL""DE&WNDV(X3J``3-Z00!2_$`"P_VA#'1Z0`!3^K:
M:,WI$JM/\``+@!A(ZDL864'=Z0HCS?@$@+T(8D`41@B:@!A!\0`!`AE!\0`#
MS>D((T_J2A,`D]WI`".T"$3JAW2P!T3J``9"Z@@"1>H$!]WI"(DP1MWI!$48
MZP((.4;>Z3@C2?$`"<WI"`%T0`_V##'1Z0`!3^K89LWI"HE/\``)@!A&ZDD6
M64'=Z1(C`99/ZIL%8D`41@::@!A!\0`!`AE!\0`#S>D&(T_J2!,`D]WI`"-/
MZIH$1.J+=$_JBG`R0]WI!F=$Z@`*1>H$"[88W>D(14?Q``=01C)&648[1LWI
M$B,`(\WI!@$?1D1`WNDZ(T_JUFH/]H0AT>D``4_JF05*ZD<:S?@$H(`864'=
MZ0HC8D`41@2:@!A!\0`!`AE/ZI@$3^J(<$3JB71!\0`#1.H`",WI!"-%Z@0)
M<P$`DT1&W>D`(TU&W>D&B4_JEPE"Z@H"W>D$JP_V("'1Z0`!B.H$",WI!$4:
MZP(*WND\14OQ``M21LWI"JLD&$_P``M-0<WI%D7=Z1)%3^K::@B92NI+&H3J
M"`3-^`2@6T:@1MWI%D5D&$7Q``44ZP@`3^J6"$_JAG1(ZH=XWND^9T7Q``'-
MZ0@!40$`D=WI``$-];A^S>D`9TCJ!`9)Z@@'W>D$B4#J"@#=Z0BKB.H&"`_V
MC!75Z0!%S>D(9QKK``K=Z0!G2_$`"\WI$JM01C893_``"V]!W>D*10:=3^K:
M:H3J"`1*ZDL:=AG-^`2@1_$`!Z!&%NL(!%E&1_$`!<WI!D5$`0"4W>D`198(
M1NJ#=I\(1.H*!-WI!JM/ZH)X`",:ZP0*3_```LWI`"-'Z@8#1NH(`E1&F49/
MZM1CD$8`D]WI""-+\0`+S>D&B0`G@NH(`EU&WND`JPWUO'X61@_VW`/3Z0`C
MS>D610`E$NL*`D/K"P/=Z1*KD$8$FIE&`)L8ZP((BNH&"D/J11,`DT_JU6,!
MD]WI`"-/ZD063^J0`TGQ``DR0P`FS>D`9QCK"@H`DT_J@7/-Z01G2?$`"P63
M&NL""`";2_$`"8X(`99#ZH%S`),%FX$'!)%"1D/JD`,%D]WI`&?"1LM&W>D$
MB=[I``$-]<!^2.H&"$GJ!PG-Z1*K3_``"T9&3T;=Z0:)3^K::LWI"F=*ZDL:
MB.H&"`_V'`?7Z0!GS?@$H%M&-AA/0<WI!&?=Z19G")F&Z@@&L$;=Z01G=AA'
M\0`'%NL(`$?Q``'-Z00!40$`D=WI``&F"$;JA7:O"$#J"@#=Z02K3^J$>``E
M&NL`"D_P``3-Z0!%1^H&!4;J"`101JE&2_$`"Z!&Q`X`E``GW>D*1<WI%JM/
M\``+A.H(!%E&WND`JPWUQ'XF1@_RB'75Z0!%S>D(B13K"@1%ZPL%H$8`G*E&
M1.I!%`"4W>D210:==$!&`1CK!0BB1D_JT60!E$GQ``G=Z0!%&.L*"DGQ``LT
M0P`FS>D`9QKK!`C-Z01G3^J2!@"63^J#=@662_$`"0">1$9-1LWI$D5&ZH-V
M`)8%G@`E3^K4:D;JD@8%EIX(`9:3!P23WND`(TKJ11K=Z0!G#?7(?MWI!(G-
M^`2@2.H&"$GJ!PE&1D]&W>D(B<WI!F>(Z@8(#_+,9]?I`&>V&%]!W>D6(X+J
M"`*01@J:MAA'\0`'%NL(`D?Q``/-Z00C8P$`D]WI`".&"$;J@7:/"$+J"@+=
MZ02K3^J`>``A&NL""D_P``#-Z0`!1NH(`%)&1^H&`4_JTF8`ELWI"@%/\``#
M`)E+\0`+#_)8:=GI`(G-Z1:K0>I#$=[I`*L-]<Q^`)$(F1CK"@C=Z09G2>L+
M"1CK`0C=Z1*K3^K380&1ANH`!MWI``&*Z@8*3^I"%D#J!@!/\``'3_``!D_J
ME`'-Z0!G2?$`"0"1&.L*"LWI!&=/ZH5Q!9%)\0`+`)D:ZP`(2_$`":X(0>J%
M<0"1!9E`1L)&RT9!ZI0!S>D(JP61I`<!ED_P``L$E$_JVFK=Z0!G2NI+&MWI
M!(E91M[I`$4-]=!^2.H&"$GJ!PG-^`2@1D9/1MWI"HG-Z1)GB.H&"`_RA%?7
MZ0!G-AEO0=WI%D4&G83J"`1V&4?Q``>@1A;K"`1/ZI(&1_$`!<WI!$5$`0"4
MW>D`14;J@W:?"$_J@GA$Z@H$W>D$JP`B`",:ZP0*S>D`(T?J!@-&Z@@"5$9+
M\0`+D$:91N,.`)/=Z1(C`"7-Z0:K@NH(`M[I`*O-Z1:)#?74?A9&#_+\0]/I
M`",2ZPH"0^L+`]WI"*N01@J:F48`FQCK`@B*Z@8*0^I%$P"33^K58P&3W>D`
M(T_JD`-#ZH%S3^I$%DGQ``DR0QCK"@H$DQ]&3^J1`P632?$`"X8'&NL""-WI
M!`%+\0`)PD;>Z0`C.4/+1LWI"JM/\``+S>D`JXE&`)DP0]WI%F<-]=A^@$;-
MZ0B)1D!/ZM%J#_)H0='I``&'Z@D'$AA+01!&&48!F]WI!HD`FHCJ!@@2GHGJ
M!PG-Z1B)$.L&"$KJ0QI!\0`)&)G-^!2@4P$8ZP$(!)-)\0`)I@A`1D;JA79)
M1MWI!(D'EJ,'!I-(Z@H(W>D&(Q#K"`I!\0`+W>D(`3)#5$:O",WI$JO=Z0JK
MD$8[0T#J"``*Z@`*`"*91@`CS>D$(^,.!)-21@";`"7>Z0!G#?7<?@_RR#O;
MZ0"KW>D(`029&NL&"D_JU68%ED_JDP8!FT'J11$$D1:9`.H(`$OK!PM&ZH-V
M`D,!FQKK`0#-Z0:)2_$``=WI!(F`&$_J1!I!\0`!S>D*`4CJ"@B?"-WI"JL`
MFQKK"`I+\0`+S>D6JY@'4D9&Z@`*WND``4?J!@L`(PWUX'[-Z00!`"#=Z09G
M`"'=Z1*)KPA&Z@H&S>D``0CJ!@C1#LWI"JM&1MWI!HD`D0CJ"@C=Z00!#_(4
M.]OI`*L0ZPH`0>L+`8)&`""+1@"9S>D2JT;J"`I!ZD,1W>D2B0"1`"'-Z00!
M60$%D:8(")E&ZH5VH`<`)1CK`0@%F4GQ``D8ZPH*0>K280613^K380&13^I"
M$0212?$`"]WI!(G-Z0BKW>D`JTCJ"@C=Z0BK&NL("MWI"HE+\0`+S>D2JU1&
M1NH`"M[I``%'Z@8+`"8`)\WI`&?F#@"6#?7D?MWI%F?-Z00!2.H*`$GJ"P$&
M0`]`W>D$`<WI%F<(Z@H(DZ?7Z0!GS>D(JX`9>4$&1@]&`)E!ZD41`)'=Z18!
M`"%`Z@@`@$8`(,WI!`&0!P:9%NL!"D_J11$%D4_JU6$!D4?Q``L%F1KK"`I+
M\0`+S>D&JT'JU&$%D6$!!)'=Z02)E@C=Z0"K1NJ#=I\(`"-(Z@H(W>D&JQKK
M"`K=Z0B)2_$`"\WI%JM21D;J``I'Z@8+2.H*!LWI!JNO"-WI$JO>Z0`!#?7H
M?@KJ!@I61MWI!JO-Z00!`"`(Z@H(`"$/\I`;V^D`J\WI``'1#@"1W>D$`1#K
M"@!!ZPL!@D8`((M&`)G-Z1*K1NH("D'J0Q'=Z1*)`)$`(<WI!`%9`061I@@*
MF4;JA7:@!P`E&.L!"`692?$`"1CK"@I)\0`+0>K28061V0X!D5$!!)'-Z0JK
MW>D$B=WI`*M(Z@H(W>D*JQKK"`K=Z0:)2_$`"\WI$JM41D;J``K>Z0`!1^H&
M"P`F`"?-Z0!GY@X`E@WU['[=Z19GS>D$`4CJ"@!)Z@L!!D`/0-WI!`'-Z19G
M".H*"#&GU^D`9\WI"JN`&7E!!D8/1@"90>I%$0"1W>D6`0`A0.H(`(!&`"#-
MZ00!D`<(F1;K`0I/ZD41!9%/ZM5A`9%'\0`+!9D:ZP@*2_$`"\WI"*M!ZM1A
M!9%A`021W>D$B98(W>D`JT;J@W:?"``C2.H*"-WI"*L:ZP@*W>D*B4OQ``O-
MZ1:K4D9&Z@`*WND``4?J!@M(Z@H&S>D(JPWU\'ZO",WI!`$`(``AS>D``=$.
M`)'=Z1*K"N``OZ_S`("AZ]EN`````-R\&X\`````W>D$`0KJ!@I61MWI"*L(
MZ@H(#_9T:]OI`*L0ZPH`0>L+`8)&`""+1@"9S>D2JT;J"`I!ZD,1W>D2B0"1
M`"'-Z00!60$%D:8(!IE&ZH5VH`<`)1CK`0@%F4GQ``D8ZPH*0>K280613^K3
M80&13^I"$0212?$`"]WI!(G-Z0:KW>D`JTCJ"@C=Z0:K&NL("MWI"(E+\0`+
MS>D8JU1&1NH`"M[I``%'Z@8+`"8`)\WI`&?F#@"6#?7T?MWI%F?-Z00!2.H*
M`$GJ"P$&0`]`W>D$`<WI!F<(Z@H(#_:L5]?I`&?-Z1*K@!EY009&#T8`F4'J
M11$`D=WI!@$`(4#J"`"`1@`@S>D$`9`'"ID6ZP$*3^I%$0613^K580&11_$`
M"P69&NL("DOQ``O-Z0:K0>K4806180$$D=WI!(F6"-WI`*M&ZH-VGP@`(TCJ
M"@C=Z0:K&NL("MWI$HE+\0`+S>D*JU)&1NH`"D?J!@M(Z@H&S>D&JZ\(W>D8
MJ][I``$-]?A^"NH&"E9&W>D&J\WI!`$`(`CJ"@@`(0_V\$O;Z0"KS>D``=$.
M`)'=Z00!$.L*`$'K"P&"1@`@BT8`F<WI%JM&Z@@*0>I#$=WI%HD`D0`AS>D$
M`5D!!9&F"`B91NJ%=J`'`"48ZP$(!9E)\0`)&.L*"D'JTF$%D4_JTV$!D4_J
M0A$$D4GQ``O=Z02)S>D(J]WI`*M(Z@H(W>D(JQKK"`I+\0`+S>D6JU1&1NH`
M"M[I``%'Z@8+W>D&B0`F`"?-Z0!GY@X`EMWI"F<-]?Q^S>D$`4CJ"@!)Z@L!
M!D`/0,WI"JO=Z00!".H*"`_V'$O;Z0"KS>D(9Y8($.L*`$;J@W9!ZPL!GPB"
M1@`CBT8`F4'J11$`D=WI"`$`(4#J"`"`1@`@S>D$`9`'$ID:ZP$*3^I%$061
M3^K580&12_$`"P69&NL("DOQ``O-Z0BK0>K4806180$$D=WI`*O=Z02)2.H*
M"-WI"*L:ZP@*W>D*B4OQ``O-Z1*K4D;-Z0`C1^H&`T;J``+>Z0`!#?4:?A]&
M`)L61D)&,D/-Z0AG3^K3:@`G%D;=Z18C,D`61D)&W>D(B0+J"`*01@_V4#/3
MZ0`C$AA+0=WI``'-Z18C1NH(`@`FS>D$9TKJ01I)`061@$8&F06>#T;=Z18!
M1NK89@66P!E'1D'Q``$0ZP((0?$`"7X!!)9"1DM&W>D$B:8(@*E(Z@H(1NJ%
M=A+K"`I/ZH1P0_$`"\WI%JM41D;J``K1Z0`!KPC=Z0B)4D9'Z@8+`"7-Z00!
M3^K4:MWI$@%&1A9#6T8P0,WI$B,(Z@((W>D$(P9&#_:H(='I``%*ZD4:S?@4
MH!(82T$01@J:&4;-Z08!1NH(`&,!!).`1MWI!@&`&-WI!"-!\0`!$.L("$+J
M"@+=Z0"K0?$`"<WI!HG=Z0")4T:>"%M&F0?=Z0:K2T9&ZHEVGPA#1AKK`@I!
MZI@!3^J#<-WI$HE+\0`+S>D*JT_P``O-Z0"K1NH`"@";1^H!"T)&5D8R0U]&
M3^K3:LWI!F<61MWI%B."J0`G,D#1Z0`!%D9"1MWI!HD"Z@@"D$8/]NP3T^D`
M(Q(82T'-Z18CW>D``4;J"`(`)LWI!&=*ZD$:20$%D8!&")D%G@]&W>D6`4;J
MV&8%EL`91T9!\0`!$.L""$'Q``E^`0260D9+1MWI!(FF"*\(1NJ%=DCJ"@B@
M!Q+K"`)&Z@`*1^H&"]WI!HF$J11&0_$``]'I``$`)<WI%B-21EM&W>D*JT9&
M%D,*Z@8*S>D(`<WI"B,(Z@((5D;=Z0@C#_9$&]OI`*L`(``AS>D$`1+K"@)/
MZM1A0^L+`P211NH("A!&FT8$FQ*:0^I%$P23ZPX%D]WI!(EC`8`80^H(`@";
MW>D`B4OQ``$0ZPH*3^J3!@&;0?$`"T;JB78:ZP(*3^J#<4M&3^J3!T-&0>J8
M`4_J@W#=Z0J)2_$`"\WI$JM/\``+S>D`JT;J``H`FT?J`0M61D)&,D-?1D_J
MTVK-Z0AG%D;=Z18CAJD`)S)`T>D``19&0D;=Z0B)`NH(`I!&#_:$`]/I`",2
M&$M!W>D``<WI%B-&Z@@"`";-Z01G2NI!&DD!!9&`1@:9!9X/1MWI%@%&ZMAF
M!9;`&4=&0?$``1#K`@A!\0`)?@$$ED)&2T;=Z02)I@BO"$;JA79(Z@H(H`<2
MZP@"1NH`"D?J!@O=Z0B)B*D41D/Q``/1Z0`!`"7-Z18C4D9;1MWI$JM&1A9#
M"NH&"LWI&`'-Z08C".H""%9&W>D8(P_RX'O;Z0"K`"``(<WI!`$2ZPH"3^K4
M84/K"P,$D4;J"`H01IM&!)L*FD/J11,$D^L.!9/=Z02)8P&`&$/J"`(`F]WI
M`(E+\0`!$.L*"D_JDP8!FT'Q``M&ZHEV&NL""D_J@W%+1D_JDP=#1D'JF`%/
MZH-PW>D&B4OQ``O-Z1*K3_``"\WI`*M&Z@`*1^H!"XJI5D9"1M'I``%?1LWI
M"F<R0P";`"<61D_JTVK=Z18C,D`61D)&W>D*B0+J"`*01@_R('/3Z0`C$AA+
M0=WI``'-Z18C1NH(`@`FS>D$9TKJ01I)`061@$8(F06>#T;=Z18!1NK89@66
MP!E'1D'Q``$0ZP((0?$`"7X!!)9"1DM&W>D$B:8(KPA&ZH5V2.H*"*`'$NL(
M`D;J``I'Z@8+W>D*B8RI%$9#\0`#T>D``0`ES>D8(U)&6T;=Z1*K1D860PKJ
M!@K-Z0@!S>D2(PCJ`@A61MWI"",/\GAKV^D`JP`@`"'-Z00!$NL*`D_JU&%#
MZPL#!)%&Z@@*$$:;1@2;!II#ZD43!)/K#@63W>D$B6,!@!A#Z@@"`)O=Z0")
M2_$``1#K"@I/ZI,&`9M!\0`+&NL""DOQ``O-Z1:KF0=+1D'JF`&?"$_P``M#
M1D;JB7:8!]WI$HE;1D?J`0N.J5)&1NH`"DCJ"@;1Z0`!S>D(J]WI&*O-Z0`C
MTPX*Z@8*5D;=Z0BK".H*"`_RR%O;Z0"K&NL`"DOK`0O=Z0`!S>D8JT;J"`K=
MZ1B)0^I!$P]&!)-+`0J9!D9#ZM9C!Y,8ZP$(3^K78TGQ``D%DQCK"@I/ZD83
M!I-)\0`+W>D$(Z8(W>D&B4;JA7:@!P`C2.H""``B&NL("MWI"(G-Z00C2_$`
M"U1&S>D*J^,.1NH`"@232.H*`-WI%B.0J:\(".H*"`)`1^H&"]'I`&<`)1!&
M#_(D4]/I`"-I`4_P``F2&7M!%D9`Z@@"3_``",WI!HD'D1]&$ID$FW88!YE#
MZD431_$`!P23LAA!ZM1A!Y%/ZM5A!9%/ZD01!I%'\0`#W>D$`<WI$B.2K]WI
M!B,`FP)#3^J3"!!&W>D2(P&9$AA/\```0_$``\WI$B-(ZH%X`9D`(T_JD0D`
MF<WI`"-)Z@@#V4:.!P`AS>D$`1E&`)M(Z@8"U^D`9]!&$$9*Z@(*VPX$D]WI
M"B/-Z0J)"^H!"0CJ``C-Z1:)#_)@2=GI`(D"Z@H"S>D&`1CK!@@!F$GK!PD$
MF49&DD9/1MWI%HE!ZD`1!)%(Z@H(P0ZR1@61")Z[1@"9&NL&"MWI!&=+\0`+
M&NL("D_J01)/ZI0!1NH"!D'JA7%+\0`+&NL&"$OQ``D$D0M&J0@%D49&PD;+
M1MWI!(FB!Y2MS>D6JTCJ`@A)Z@,)U>D`14_P``M"1DM&W>D&B4_JVFK-Z0@C
M2NI+&HCJ`@COH]/I`"/-^!2@7T82&6M!%$8=1MWI$B."Z@@"D$8*FJ081?$`
M!13K"`)%\0`#$$891G,!!)/=Z00C`)M"Z@H"$.L""D'Q``L!F9P(`9O-Z0JK
M4D:-"`"91.J#=$_P``M/ZMIJ6T9/ZH%XEJE*ZDL:T>D``<WI``%$Z@@`1>H$
M`=WI"(D$1@U&B.H`",WI!$7=Z0`!RJ75Z0!%S?@$H``9:4$$1@U&S>D21=WI
M%D4&F83J"`2@1MWI$D5D&$7Q``44ZP@`3^J6!$7Q``%$ZH=TO0B8KT_JAGC-
MZ08!40'7Z0!G`)'=Z0`!S>D`9T3J"`;=Z02)0.H*`-WI!JM%Z@0'B.H&"*ZE
MU>D`1<WI!F<:ZP`*W>D`9TOQ``M01LWI$JLV&4_P``MO0=WI"D4(G4_JVFJ$
MZ@@$2NI+&G89S?@$H$?Q``>@1A;K"`191D?Q``7-Z0A%1`$`E-WI`$66"$;J
M@W:?"$3J"@3=Z0BK3^J">!KK!`I+\0`+5$9/ZMIJ74;-Z0I%WND`(P`E2NI%
M&@WU('[-Z0`C1NH(`MWI!HE'Z@8#AZ?7Z0!GS>D((XCJ`@C=Z0`CS?@$H)(9
M>T$61A]&W>D2(X+J"`*01@2:MAA'\0`'%NL(`D?Q``/-Z00C8P$`D]WI`".&
M"$;J@79/ZH!X0NH*`MWI!*N/")RI&NL""D_P``-+\0`+S>D2JU)&1NH("MWI
M"(E'Z@8+T>D``=8.S>D$JXCJ"@@/\I0;V^D`JQKK``I+ZP$+1NI#$=WI"F?-
MZ1:K3^I"&H;J"`8`D0:9L$;=Z19G=AA/ZM-A1_$`!Q;K"`!/ZI0&`9%&ZH5V
M1_$``:\(GJU/ZH1XS>D&`=7I`$7=Z0`!S>D`14;J"`3=Z02)0.H*`-WI!JM'
MZ@8%B.H$"$>GU^D`9\WI!D4:ZP`*W>D`14OQ``M01LWI"JND&4_P``M]04_J
MVFHF1DKJ2QHO1MWI$D4(G5E&A.H(!,WX!*!V&4?Q``>@1A;K"`1/ZI(&1_$`
M!4;J@W:?"$_J@GC>Z0`C#?4F?LWI"$5$`0"4W>D`1<WI`"-&Z@@"W>D&B43J
M"@3=Z0BK1^H&`XCJ`@@CI]?I`&?-Z0@C&NL$"MWI`"-+\0`+5$9/ZMIJDAE=
M1GM!S>D2119&`"4?1MWI"B-*ZD4:S?@$H(+J"`*01@2:MAA'\0`'%NL(`D?Q
M``/-Z00C8P$`D]WI`".&"$;J@79/ZH!X0NH*`MWI!*N/"**I&NL""D_P``-+
M\0`+S>D*JU)&">"O\P"`W+P;CP````#6P6+*`````$;J"`K=Z0B)1^H&"]'I
M``'6#HCJ"@C-Z02K#_*L>]OI`*L:ZP`*2^L!"T;J0Q'=Z1)GS>D6JT_J0AJ&
MZ@@&`)$&F;!&W>D69W883^K384?Q``<!D1;K"`!/ZI0&1_$``4;JA7;-Z08!
MKPC=Z0`!I*U/ZH1X0.H*`-7I`$7=Z0:K&NL`"LWI`$5+\0`+1NH(!,WI$JM'
MZ@8%W>D$B5!&S>D&14_P``L/\B!WU^D`9XCJ!`C=Z0!%3^K::DKJ2QK-^`2@
MI!E91GU!)D8O1MWI"D4(G83J"`1V&4?Q``>@1A;K"`1/ZI(&1_$`!4;J@W:?
M"$_J@GC>Z0`C#?4L?LWI"$5$`0"4W>D`1<WI`"-&Z@@"W>D&B43J"@3=Z0BK
M1^H&`XCJ`@@/\J!GU^D`9\WI"",:ZP0*W>D`(TOQ``M41D_JVFJ2&5U&>T'-
MZ0I%%D8`)1]&W>D2(TKJ11K-^`2@@NH(`I!&!)JV&$?Q``<6ZP@"1_$``\WI
M!"-C`0"3W>D`(X8(1NJ!=D_J@'A"Z@H"W>D$JX\(J*D:ZP(*3_```TOQ``O-
MZ1*K4D9&Z@@*W>D(B4?J!@O1Z0`!U@Z(Z@H(S>D$JP_R!&O;Z0"K&NL`"DOK
M`0M&ZD,1W>D*9\WI%JM/ZD(:ANH(!@"1!IFP1MWI%F=V&$_JTV%'\0`'%NL(
M`$_JE`8!D4;JA79'\0`!KPBJK<WI!@%/ZH1XU>D`1=WI``'-Z0!%1NH(!-WI
M!(E`Z@H`W>D&JT?J!@6(Z@0(#_*(5]?I`&?-Z09%&NL`"MWI`$5+\0`+4$;-
MZ0JKI!E/\``+?4%/ZMIJ)D9*ZDL:+T;=Z1)%")U91H3J"`3-^`2@=AE'\0`'
MH$86ZP@$3^J2!D?Q``5&ZH-VGPA/ZH)XWND`(PWU,G[-Z0A%1`$`E-WI`$7-
MZ0`C1NH(`MWI!HE$Z@H$W>D(JT?J!@.(Z@((#_+X1]?I`&?-Z0@C&NL$"MWI
M`"-+\0`+5$9/ZMIJDAE=1GM!S>D2119&`"4?1MWI"B-*ZD4:S?@$H(+J"`*0
M1@2:MAA'\0`'%NL(`D?Q``/-Z00C8P$`D]WI`".&"$;J@79/ZH!X0NH*`MWI
M!*N/"*ZI&NL""D_P``-+\0`+S>D*JU)&1NH("MWI"(E'Z@8+T>D``=8.B.H*
M",WI!*L/\EQ+V^D`JQKK``I+ZP$+1NI#$<WI%JM/ZD(:`)'=Z1)G!IF&Z@@&
ML$;=Z19G=AA/ZM-A1_$`!Q;K"`!/ZI0&`9%&ZH5V1_$``:\(L*U/ZH1XS>D&
M`=7I`$7=Z0`!S>D`14;J"`3=Z02)0.H*`-WI!JM'Z@8%B.H$"/BGU^D`9\WI
M!D4:ZP`*W>D`14OQ``M01LWI$JND&4_P``M]04_JVFHF1DKJ2QHO1MWI"D4(
MG5E&A.H(!,WX!*!V&4?Q``>@1A;K"`1/ZI(&1_$`!4;J@W:?"$_J@GC>Z0`C
MS>D(140!`)3=Z0!%S>D`(T;J"`+=Z0:)1.H*!-WI"*M'Z@8#B.H""-:GU^D`
M9\WI"",:ZP0*W>D`(TOQ``M41D_JVFJ2&5U&>T'-Z0I%%D8`)1]&W>D2(\WI
M%F=*ZD4:@NH(`LWX!*"01@2:%T;=Z18CTAE#\0`#$NL(!D_JD`)#\0`'0NJ!
M<F,!`).+"+2I3^J`>,WI!&?=Z0!GT>D``4;J"@;=Z02KS>D``4+J"`#=Z0B)
M0^H"`;*CT^D`(QKK!@K-Z00!B.H`"-WI``%+\0`+5D;-Z1*K@!A/\``+64%/
MZMIJ`D9*ZDL:"T;-Z18CW>D*(U]&S?@$H(+J"`*01@::$4;=Z18C4AA#\0`#
M$NL(`$_JE`)#\0`!0NJ%<G,!`).K"+:M3^J$>,WI!@'5Z0!%W>D``<WI`$5"
MZ@@$W>D$B4#J"@#=Z0:K0^H"!8CJ!`C=Z0`CS>D*11KK``J(I=7I`$5+\0`+
M4$;-Z0:K$AE/\``+:T%/ZMIJ%$9*ZDL:'4;=Z1(CS?@$H%E&@NH(`I!&")JD
M&$7Q``661A3K"`)/ZI8$1?$``\WI""-#`0"3W>D`(T3JAW2]"$_JAGA"Z@H"
MW>D(JP`F`"<:ZP(*S>D`9TOQ``N/"%)&1.H("EM&1>H$"[BMS>D2(]0.`)35
MZ0")`"-CI=7I`$56`02=3_``"1CK!`@`G!CK!0C-Z0BK1.I#%`"4W>D*183J
M"@2%Z@L%S>D$1=P.W>D&JP&4W>D$183J"@08ZP0*A`?01MWI`*M/\``+2NH&
M"H8(&.L*"$;J@7:ZJ<)&3_``",WI!JM`1M'I`*M)1LWI!`%&Z@0`1^H&`=WI
M!F<$1@U&S>D617D!!9$_H='I``%/ZM9H2.I'&!#K"@!!ZPL!W>D(J\WI``&*
MZ@0*!9B+Z@4+0.K6851&LD;=Z1)G748%D69`;T`*F0`DS>D29P`EW>D`9R!&
ME`AV&%%&20$$D2E&S>D``1*91.J#=!;K`0K=Z00!G@>3!T#J"``!E@"3&NL`
M!@&4W>D"`0`AW>D`JQJ;@!G=Z12)2NH$"@B:3_``"</I``$8ZP((W>D&`=WI
M#&<;FC88O9Q/0=WI$`'-Z0!G`"$5:-WI#F<6FL/I"(F`&!;K"@:L0K)&W>D`
M9T_P``=21L/I`F=/\``#&I_'Z08!Q^D$(P/1#?4_?;WH\(_\]^CJK_,`@-;!
M8LH``````"@\T"WI^$-+\C@3P/("`]/X`)"Y\0`/+M`%>#TM&+\`+12_`24`
M)171V?@`0'RQ@$8/1DY&($9!1BI&_/?JZQ"Y8UT]*P_05O@$3P`L\M$@1KWH
M^(,%1A7X`3\]*QB_`"OYT2T:X.?)ZP8&:!P@1+80/F"]Z/B#2$:]Z/B#<$?P
MM4OR0!;`\@(&@[`S:$OR.!<%1L#R`@<!DRA&:4;_]Z__J+$`G#EH`>N$`UIH
M0?@D(``J\=`$,U/X!"]#^`0L`"KYT2A&:4;_]YK_`"CIT0&:,VB:0@'1`[#P
MO?SW<NHMZ?!/2_)`%0MXP/("!0Q&*F@]*X6P"+\!-`9&`Y(@1OSWX.H"J0=&
M,$;_]WG_@D8`*%?0_/?6ZH="2MD"FTOR.!G`\@()3^J#"#%X/2D8OP`I%+\!
M(0`A!]`Q1A'X`3\]*QB_`"OYT8D;N!S9^`"0"$1+\C@7_/>2ZL#R`@=)^`@`
M`"ANT#IH<1P"F#-X4O@@```K&+\]*P-P"=!"'!'X`3L01@`K&+\]*P+X`3OV
MT0)&/2,#<!3X`3L"^`$_`"OYT0`@`YHK:)I"3M$%L+WH\(\*\?\P%/@!.P#X
M`3\`*_G1[N=+\C@9P/(""=GX`+#;^```F+-;1E/X!"\*\0$*`"KYT0KQ`@&)
M`$OR:!/`\@(#&FB"L5A&_/?XZ<GX````LT_JB@@#1@KQ`0(`(4/X(A#-^`B@
MB.<(1@$B&F#\]R[J`9!PL4_JB@A91D)&_/>.Z=WX!,!C1LGX`,#DYX)&""'2
MYT_P_S"LY_SWO.D`ORWI\$%+\D`5P/("!9ZP*V@=DQ"Q`W@'1C.Y'9HK:)I"
M4M$>L+WH\('\]_3I!D8`*//0,$;\]Z;JF+/"?"XJ-]``\1,$.$;\]Q;J@$8@
M1OSW$NI`1`(P_/?JZ4;R+'/`\@$#`2%/\/\R`90`EX!&_/<@ZD%&`R`"JOSW
MGNH!,$!&!=`&FP/T<$.S]8!/&=#\]X#I0$;\]SCI,$;\]W3J`"C+T3!&_/>F
MZCA&_/=,Z;3G`GT`*KW0+BK"T4)]`"JXT+[G__>=_^3G_/=4Z7"U2_)(%,#R
M`@0@:/SWDNK0^(`P(&A>:/SWC.J0^&50(&C\]XCJ!?!_!4-H&XK#\P@#1>K#
M%76`(&C\]WSJT/B`,"!H76C\]W;J1O8\(0`BP/(!`?SWNNGH82!H_/=JZM#X
M@#`@:%UH_/=DZM#XX#0@:"MB_/=>ZM#X@#`@:%UH_/=8ZM#X_#`KL2!H_/=2
MZM#X_#`;;VMB`"4@:/SW2NK0^(`P(&A;:)UB_/=$ZM#X@#`@:%MHG6'\]SSJ
MT/B`,"!H7&C\]S;JT/@8,N-B<+TXM4OR2!3`\@($!48@:/SW*NHI1@#UA'(#
M(/SW&.H(L0`@.+T@:/SW'NK0^!@Q`_1P0[/U@$\)T"!H_/<4ZM#X&#$#]'!#
ML_4@3^G1*$8"(?SWLNFP^H#P0`DXO?"U2_)`%*WU@%W`\@($@[`C:`WU@%4&
M1@0U1O(T<`]&P/(!``&I0/;_<BM@_/?,Z``H(]U%'@&K6EWJL05&`:@O(2I&
M_/>$Z<"Q2_)($\#R`@,8:/SWV.DQ1@&J*T;\]YSI#?6`4P0S&F@C:)I"$=$-
M]8!=`[#PO0`MX-%+\D@3P/("`QAH_/?`Z3%&.D;\]Y;HYN?\]W+H2_)($\#R
M`@,0M1AH_/>PZ4;R1'%!\A!B1O*P8\#R`0'`\@$"P/(!`[WH$$#\]PRY$+5+
M\D@4P/("!(*P(&C\]YCI__?=_R!H_/>2Z4;V/"-&\F!Q1O+A(L#R`0/`\@$!
M`)/`\@$"`"0!E/SW(.D"L!"]`+]PM4OR0!2M]0!=P/("!(:P(V@-]0!2%#(3
M8/SWGNA&\H1R1O)X<\#R`0+`\@$#`9(!(4'R`0(`D`.H_/>XZ``H(ML-]8!1
M`ZA/](!2$#'\]S;H!1X8VV@<_/=FZ`9&J+$-]8!1*D80,?OWV.\P1@`C<U4-
M]0!3%#,::"-HFD(&T0WU`%T&L'"]`"#RY_'G^_?P[P"___>TORWI\$]+\D`6
MK?6`7<#R`@:'L#-H#?6`4@1&%#)&\HQP#T;`\@$`!*D38/_W\_PO(05&($;\
M]USHH+%&\IAP(4;`\@$`__=6_2!&#?6`4Q0S&F@S:)I"0/"0@`WU@%T'L+WH
M\(\@1OSW..A&\JAQP/(!`8%&.$;\]Z;H@D8`*-S01O*(=T;RM'C`\@$'P/(!
M")KX`#``*PB_ND8ML2A&44;[]T;O`"A,T%!&_/<6Z`KK``,3^`$\+RL(T4,>
M`"%31!EP`3@3^`$M+RKYT`GQ`0,81+#U@%^PVD;RK'-+\D@;`2%/](!2P/(!
M`\WX`*#-^`2`!:@"E,#R`@O\]PSHV_@``/SWL.@%J0#UA'(#(/SWANA0N=OX
M``#\]Z3HT/@8,0/T<$.S]0!/%M!&\JAQ`"#`\@$!_/=&Z()&NO$`#Z?1>^=&
M\JAQP/(!`?SW/.B"1KKQ``^<T7#G!:@!(?SW+.@`*.+11O*8<`6IP/(!`/_W
MP?P%J/OWW.]GY_OW+N\`OP-X.[%"'"\K"+\01A+X`3L`*_C1<$<`OSBUB+,%
M>`1&=;/[]YKO`3@C&)Q"#-(B7"\J+]%:'@+@&7@O*2K1HD(31@+Q_S+WT9Q"
M%]`!.P+@$7@O*031G$(:1@/Q_S/WTQ(;DQRS]8!?$M@A1@$R3_2`4Q)(^_?J
M[A!(.+TO+131`B#[]T;O`T80L2XB&H`XO0`@.+U:'@+@&7@O*=;0E$(31@+Q
M_S+WT\[G1O*T<,#R`0"]Z#A`^_=YOP"_;+$"`/"UC;!?30*L2_)`%L#R`@8/
MS3=H#\0/S0N7+6@/Q$;RN'#`\@$`)8#_]Q3\1O+$<,#R`0#_]P[\1O+,<,#R
M`0#_]PC\1O+8<,#R`0#_]P+\1O+@<,#R`0#_]_S[1O+P<,#R`0#_]_;[1O*,
M<,#R`0#_]_#[1O+\<,#R`0#_]^K[1O8(`,#R`0#_]^3[1O84`,#R`0#_]][[
M1O*8<,#R`0#_]]C[1O8@`,#R`0#_]]+[1O8L`,#R`0#_]\S[1O8X``&IP/(!
M`/_WA?L!1BBQ1O8(`,#R`0#_]^W[1O9,``&IP/(!`/_W=OL!1BBQ1O9@`,#R
M`0#_]][[1O9L``&IP/(!`/_W9_L!1JBQ1O*,<,#R`0#_]\_[1O+@<$;VG`'`
M\@$`P/(!`?_WQ?L+FC-HFD(ET0VP\+U&]GP``:G`\@$`__=(^P%&,+%&\OQP
MP/(!`/_WL/O?YT;VD`$-\1D`P/(!`0HB^_=`[P`HU-%&\OQP#?$C`<#R`0#_
M]YS[R^?[]PSN`+^\9@$`,+5+\D`42_(L%<#R`@0C:,#R`@6#L"AH`9-#'`70
M`9HC:)I"$M$#L#"]1O+\<&E&P/(!`/_W"OLPL0!X`"@8OS`H%+\!(``@*&#H
MY_OWX.T(M?OWG.W[]X[M`+$`:`B]+>GP1P=&*TR.L`:M2_)`&,#R`@@/S-CX
M`&`/Q93H!P`&G`V6A>@'`.RQ1O*H>0:MP/(!"0;@.4;[]V#MV+%5^`1/A+$@
M1@6I__?0^@9&$+$#>``K[]$@1CE&__<W^U7X!$\`+.[1#9K8^``PFD(?T0ZP
MO>CPASA&^_<:[H)&,$;[]Q;N4$0",/OW[NU&\JQSC>B``L#R`0,"E@$A3_#_
M,H)&^_<D[B!&44;_]P_[QN?[]W[MX&8!`"WI\$\%1L5,K?4!39&P2_)`$P3Q
M#`X2KI3H!P#`\@(#T_@`P!BO"9,D-`WQ5`@-]0%)AN@'``GQ/`F^Z`\`R?@`
MP`_'GN@#`(?H`P"4Z`<`B.@'`$;RC'`1J<#R`0#_]VGZ(+$#>`1&`"M`\(B!
M__=C_P=&`"A0T#A&^_>^[4```3#[]Y;M.GB`1@1&>K%&]J@#`)(@1D_P_S+`
M\@$#`2'[]\CM%_@!+P(T`"KOT1B8&*P8N13@5/@$#XBQ$:G_]SGZ!T8`*/;0
M`W@`*_/0__<G_``H[]`X1OOWNNV!1F"[$IQ$LR-X`2<SN23@5O@G0`RS(W@!
M-_.Q($;_]Q'\`"CTT"!&^_>D[0`H[]"!1A3@^_>>[0`H0/`^@5CX!`L`*`#P
M,X$1J?_W!?H`*/70`W@`*_+0[.=/\``)2$9&\K1W^_=:[<#R`0<$1D!&^_=4
M[2!$`/($1"!&^_<J[4;VO`)&]K`#P/(!`L#R`0,!(0*23_#_,LWX`)#-^`R`
M`9<&1OOW6.TP1D_TX''[]W#M`3`KT$OR2!C`\@((V/@``/OW\NTQ1@#UA'(#
M(/OWX.V0LTOR4!%&]D02P/("`2MH"&C`\@$"`)8!(?OW=.T`(`WU`4,\,QIH
M"9L;:)I"0/"^@@WU`4T1L+WH\(_[]Q[M`6@1*<[02_)0$$;VQ`+`\@(`*V@`
M:,#R`0(!D0$A`);[]U+M`"#;Y]CX``#[][3MT/@8,0/T<$.S]8!/P='8^```
M^_>H[=#X()'[]QSL@46WT=CX``#[]Y[MT/@8,</S"`.S]>!_K-$@1OOWJNP1
MJ01&1O:0(,#R`0#_]V3Y`"@`\'*"U?@`@/OW[.P!1D!&__=/_(!&`"@`\&:"
M0$;[][3L`RB!1A+=!#A&]@`10$3`\@$!^_?6ZTBYN?$$#P#P[8'!1!GX!3PO
M*P#PYX'_]Q3^`48HN4!&^_=N[`R0`"ADT4;R_'!&]IP!P/(!`<#R`0#_]YCY
M1O8\*?OW>NQ&]B`3`9?`\@$#`);`\@$)`2'-^`R03_#_,D_P``@"D"!&^_>2
M[#M&1T:81AK@`+_\9@$`^_>"[`-H$2L:T?OW6NQ&]C`3`3<`E@.7*D;-^`2`
MP/(!`\WX$)`!(0*0($;[]W+L($9/].!Q^_>*[$,<!4;?T#!&^_>4ZT;RC'`A
M1L#R`0#_]U#Y($;_]^?]($8GY__WX_T@1OOW9.PAYT;VH`<-(,#R`0=UY@=&
M;N9/\/\S;_`1`@(E`)7[]^;K3ZD,F`8B^_=:ZYWX/#$CN9WX/3%#*P#PDX$`
M)0`B`)4`(PR8^_?2Z^2AT>D``>2CT^D`(P_RE#G9Z0")S>D@`2RI/)7-Z2(C
M#4;AH]/I`"/BH='I``'-Z22)J4;-Z1XCS>DF`0`@`"$-E,WI*`'-Z2H!#I8/
MEPR83ZE/]`!"^_<>Z[#Q``A\W=WI*"-$1D_JR`;E%Q;K`@I/\``+FT5/ZL4'
M"+^214?J6'?=Z2HC`M(!,D/Q``-A#SR80>K%`0:1:0\'D=WI!D7-Z2BKI!A=
M02)&*T;-Z2HC`"A/T,#Q0`H>J\)%`/$X`!A$3ZFHO\)&4D;[]P+K/)M31#R3
M0"NZT4^K'JC*ZP@(FD3[]]K]N/$_#RK="O%`#,WI"F?#1DY&YD:N\4`$-T8@
M:!`T5/@,'#U&5/@(+!`W5/@$/'1%#\7RT:CQ0`@>J/OWN_VX\3\/!/%`#N7<
MJ_%`"+%&3^J8$UH<J.N#&`KK@AI11DA&0D9((_OW&.O-^/"`?.<-]9YZQ><,
MJ-'(^_<6[!ZK*)V`(-WXJ(#%\\4"F1A3'#@K@?@X``+Q.0``\[&`'JO"\3<"
M&$0`(?OWC.L>J$_J&&)/ZAA#C?CK@(WX[U!/ZA@HC?CH(`WUB'J-^.DP*PZ-
M^.J`#?(/&8WX[#`K#"T*C?CM,(WX[E#[]V7]W?AXP`WQ_`C=^(#@(I@DF4_J
M'$4FFT_J'&*-^/_`3^H<+(WX_5!51HWX_L!/ZAYLC?@#X8WX`,%/ZAY,C?@'
M`4_J'BZ-^`L1C?@"X4_J$&Z-^`\QC?@$X4_J$$Z-^/P@``J-^`7A3^H1;HWX
M!@$(#(WX".$)"D_J$VZ-^`D!C?@!P1@,C?@*$1L*C?@,X8WX#0&-^`XQ`>`8
M^`$O1O:H`P"2*$;`\@$#`2%/\/\R^_?PZLA%!?$"!>[11O8\(D;V$!,`EL#R
M`0(!EP`E`Y+`\@$#S?@(H"!&`2%/\/\RBO@H4/OWUNIJYFUH`"T_]!6N*$;[
M][#J`RA_]@^N!#A&]@@1*$3`\@$!^_?2Z0`H"+^H1@+F'JO"\3\"&$0`(?OW
MVNH>J/OWT?P`(RR3+9,NDR^3,),QDS*3,Y,TDS63-I,WDSB3.9,[YYWX/C%!
M*W_T:*Z=^#\Q0RM_]&.NG?A`,4@K?_1>KIWX03%%*W_T6:X`E4_P_S,,G6_P
M.0(H1OOW*.I/J2A&*2+[]Y[I1O8\(D;V$!-/J<#R`0("D0.2P/(!`XWHP``@
M1@$A3_#_,OOW<.H$YM7X`("6Y?OWS.FO\P"`B:O-[P````#^W+J8`````'94
M,A```````2-%9P````#PX=+#`````"WI\$]+\D`3A;#`\@(#2_)(%P&3P/("
M!QMH.&@#D_OW[.H!(P*I@/AA,$;RX'#`\@$`_O>Y_ABQ`W@Q*P#PYH#_]\CZ
M.&A,\F`F^_?6ZD;VF!'`\@$!`2(+(_OW\.D`*`#PV8#`\@(&`FE6^/0\`2O2
M^!B`0-U+\D@9`"7`\@()`20*X!%I6$;[]QSI5OCT/'B[`30!-:-"*]TX:/OW
MK.I!1BI&`"/[]U[J@D8`*`#PIH`":$_T@&-6^/`,P/(@`Y%H4/@DL`M`L_6`
M;]K0V?@``/OWDNH"(]KX`!``(OOW>.D!1EA&^_?NZ%;X]#P`*,_06AZJ0G/0
M.&A+\D@4^_=\ZD;VH!'`\@$!`2(#(\#R`@3[]Y3I!4:`L2!H^_=LZBMI1O:D
M$L#R`0(9:/OW/NDK:1MHFVA;`@#QP(`X:$OR2!3[]UKJ1O:L$<#R`0$!(@,C
MP/("!/OW<ND%1IBQ1O*8<`*IP/(!`/[W'OZ`1B!HN/$`#P#P@H#[]S[J*VE"
M1AEH^_<4Z3AH2_)(&?OW-.H`(@*I3/)@),#R`@G`\@($`T9&\HQPP/(!`(/X
M82#^]_O]@$9&^.P,@+-/].!Q^_>0Z4(<`T81*!B_`2H`\H:``9L#FAMHFD)^
MT06PO>CPCP$KB=T!)#AH`33[]P;J04;[]XSH5OCT/*-"]-Q\YU;X]#Q:'JI"
M?_1WK^GG0W@`*S_T&*\4Y\#R`@9MYU3X\`S_]RC[1/CL#``H3]`J:4_T@&/`
M\B`#$FB1:`M`L_6`;S'1$&E6^/!,(4;[]VSH*VG4^`"`3_2`8L#R(`(<:*-H
M&D"R]8!O!D82T2)I1O;4$$%&,T;`\@$`^_<<Z?OWO.DJ:5;X\#P0:!EH_O>Q
M_WKG.&C[][+I*6D`(@(C"6C[]YCH`D;BY]GX``#[]Z;I*6E"1@(C"6C[]XSH
MP^<@:/OWG.DK:1EH^_<DZ3?G1O:P$,#R`0#[]^[H^_=(Z%3X\!Q&]OP00D;`
M\@$`"6C[]^+H.+4%1O_W&OD#>`1&.[%"'"\K"+\41A+X`3L`*_C1__<E^@`H
M&+\`+0K0*WA#L4;VO`$@1L#R`0'Z]\;OA$(`T#B]*$:]Z#A`_O=>OA"U2_)(
M%,#R`@0@:/OW5NE/\/\Q^_=0Z"!H^_=0Z47RI3'`\@$!`"*]Z!!`^_<:N:_S
M`(`"2WM$`[$;:/KW_K_22@$`+>GX0P=&#$Z(1@Q-D49^1/KW@N]]1'8;MA`*
MT`0]`"0!-%7X!#\X1D%&2D:81[1"]M&]Z/B#`+]N2`$`9$@!`'!'`+\(0"WI
M"("]Z`$``@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(`````!P:@$`@&H!`(AJ`0"0:@$`F&H!`*QJ`0``````:&H!`(AG
M`0``````8&@!`&1H`0!<:@$`D&<!`&1J`0``````2&H!`%!J`0``````)7,O
M)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N
M````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\`
M``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)5
M1P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%
M04X]```Q````4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P
M97)L`````#````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`
M````5$5-4$1)4@!435``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%4
M2`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0
M051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!
M4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y
M<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*
M?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N
M;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O
M=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D
M;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT
M('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@
M;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS
M92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN
M="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M
M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE
M<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*
M<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R
M96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]
M"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*
M?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X
M="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI
M('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M
M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L
M("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`)'3_?P$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````)T;`0"%&P$`````
M``$````!`````0````4"```!````$`(```$````:`@```0```&D"```!````
MO`,```$```#B`P``#````'@5`0`-````I&8!`!D```#<K@(`&P````0````:
M````X*X"`!P````$````]?[_;[0!`0`%````=`P!``8```!T!0$`"@```&(%
M```+````$````!4``````````P````"P`@`"````*`(``!0````1````%P``
M`%`3`0`1````&!,!`!(````X````$P````@```#^__]ON!(!`/___V\#````
M\/__;]81`0``````````````````````````````````````````````````
M``````````````#HK@(```````````"$%0$`A!4!`(05`0"$%0$`A!4!`(05
M`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!
M`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`
MA!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$
M%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05
M`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!
M`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0````````````````#_____
MN&H!`$=#0SH@*$1E8FEA;B`T+CDN,BTQ,"D@-"XY+C(`1T-#.B`H1&5B:6%N
M(#0N."XS+3$S*2`T+C@N,P!!-````&%E86)I``$J````!3<M00`&"@=!"`$)
M`@H$$@03`10!%0$7`Q@!&0$:`AL#'`$B`0`N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
M97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB
M=71E<P`````!````A!4!``````````P`!````)05`0`````````,``$```"8
M%0$`````````#``'````6!8!``````````P``0```%P6`0`````````,``<`
M``"@%P$`````````#``!````I!<!``````````P`!P```+`7`0`````````,
M``$```"T%P$`````````#``'````@!@!``````````P``0```(08`0``````
M```,```D80`D9``D=```````````````````````````````````````````
M```````````````+`````0````(```!4`0$`5`$``!D```````````````$`
M````````$P````<````"````<`$!`'`!```@```````````````$````````
M`"$````'`````@```)`!`0"0`0``)```````````````!``````````T````
M]O__;P(```"T`0$`M`$``,`#```%``````````0````$````/@````L````"
M````=`4!`'0%````!P``!@````$````$````$````$8````#`````@```'0,
M`0!T#```8@4``````````````0````````!.````____;P(```#6$0$`UA$`
M`.`````%``````````(````"````6P```/[__V\"````N!(!`+@2``!@````
M!@````,````$`````````&H````)`````@```!@3`0`8$P``.`````4`````
M````!`````@```!S````"0```$(```!0$P$`4!,``"@"```%````#`````0`
M```(````?`````$````&````>!4!`'@5```,```````````````$````````
M`'<````!````!@```(05`0"$%0``8`,`````````````!`````0```""````
M`0````8```#H&`$`Z!@``+Q-``````````````@`````````B`````$````&
M````I&8!`*1F```(```````````````$`````````(X````!`````@```*QF
M`0"L9@``$$``````````````!`````````"6`````0``<((```"\I@$`O*8`
M``@````-``````````0`````````H0````$````"````Q*8!`,2F```$````
M```````````$`````````*L````.`````P```-RN`@#<K@``!```````````
M````!`````````"W````#P````,```#@K@(`X*X```0```````````````0`
M````````PP````$````#````Y*X"`.2N```$```````````````$````````
M`,@````&`````P```.BN`@#HK@``&`$```8`````````!`````@```#1````
M`0````,`````L`(``+```"0!``````````````0````$````U@````$````#
M````)+$"`"2Q```0```````````````$`````````-P````(`````P```#BQ
M`@`TL0``1!``````````````"`````````#A`````0```#``````````-+$`
M`#H```````````````$````!````Z@````,``'```````````&ZQ```U````
M```````````!``````````$````#``````````````"CL0``^@``````````
+`````0``````````
